@@ -1,13 +1,11 @@
-from __future__ import absolute_import, division, unicode_literals
-
-from .compat import PY3_ORDERED_DICT, string_types
+from .compat import string_types
 
 
 class JSONBackend(object):
     """Manages encoding and decoding using various backends.
 
     It tries these modules in this order:
-        simplejson, json, jsonlib, yajl, ujson
+        simplejson, json, ujson
 
     simplejson is a fast and popular backend and is tried first.
     json comes with Python and is tried second.
@@ -100,15 +98,12 @@ class JSONBackend(object):
 
         self.load_backend('simplejson')
         self.load_backend('json')
-        self.load_backend('jsonlib', 'write', 'read', 'ReadError')
-        self.load_backend('yajl')
         self.load_backend('ujson')
 
         # Defaults for various encoders
-        sort = not PY3_ORDERED_DICT
-        json_opts = ((), {'sort_keys': sort})
+        json_opts = ((), {'sort_keys': False})
         self._encoder_options = {
-            'ujson': ((), {'sort_keys': sort, 'escape_forward_slashes': False}),
+            'ujson': ((), {'sort_keys': False, 'escape_forward_slashes': False}),
             'json': json_opts,
             'simplejson': json_opts,
             'django.util.simplejson': json_opts,
@@ -140,7 +135,6 @@ class JSONBackend(object):
         return True
 
     def load_backend(self, name, dumps='dumps', loads='loads', loads_exc=ValueError):
-
         """Load a JSON backend by name.
 
         This method loads a backend and sets up references to that
@@ -264,6 +258,9 @@ class JSONBackend(object):
         See the appropriate encoder's documentation for details about
         the supported arguments and keyword arguments.
 
+        WARNING: If you pass sort_keys=True, and the object to encode
+        contains ``__slots__``, and you set ``warn`` to True,
+        a TypeError will be raised!
         """
         self._encoder_options[name] = (args, kwargs)
 
